const db=require('../config/database');

exports.takeQuiz=async(req,res)=>{
    const {quiz_id,user_id}=req.params;
    try{
        const[assigned]=await db.query(`SELECT* from user_quizzes where user_id=? and quiz_id=? and status='pending'`,[user_id,quiz_id]);
        if(assigned.length===0){
            return res.json({message:'Quiz completed or not assigned properly'});
        }
        const[quiz]=await db.query(`select id,title,description from quizzes where id=?`,[quiz_id]);
        const[questions]=await db.query(`select q.id as question_id, q.question_text,
            o.id as option_id, o.option_text
            from questions q
            join options o on q.id=o.question_id
            where q.quiz_id=?
            order by q.id,o.id`,[quiz_id]);
            const questionsMap = {};
            for (const row of questions) {
                if (!questionsMap[row.question_id]) {
                    questionsMap[row.question_id] = {
                    question_id: row.question_id,
                    question_text: row.question_text,
                    options: []
                    };
                }
            questionsMap[row.question_id].options.push({
                option_id: row.option_id,
                option_text: row.option_text
            });
        }
        return res.json({
        quiz: quiz[0],
        questions: Object.values(questionsMap)
    });
    }
    catch(err){
        return res.json({message:"Error fetching quiz",error:err.message});
    }
};

exports.submitQuiz = async (req, res) => {
  const { user_id, quiz_id, answers } = req.body;
  try {
    let score = 0;
    const total = answers.length;
    for (const ans of answers) {
      const [correct] = await db.query(
        'select is_correct from options where id = ?',
        [ans.selected_option_id]
      );
      const isCorrect = correct[0]?.is_correct === 1 ? 1 : 0;
      if (isCorrect) score++;
      await db.query(
        `insert into user_answers (user_id, quiz_id, question_id, answer, is_correct)
         values (?, ?, ?, ?, ?)`,
        [user_id, quiz_id, ans.question_id, ans.selected_option_id, isCorrect]
      );
    }
    await db.query(
      `insert into results (user_id, quiz_id, score, total)
       values (?, ?, ?, ?)`,
      [user_id, quiz_id, score, total]
    );
    await db.query(
      `update user_quizzes set status = 'completed' where user_id = ? AND quiz_id = ?`,
      [user_id, quiz_id]
    );
    return res.json({ message: 'Quiz submitted', score, total });
  } catch (err) {
    return res.status(500).json({ message: 'Error submitting quiz', error: err.message });
  }
};














